# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cot2tot']

package_data = \
{'': ['*']}

install_requires = \
['imageio>=2.37.0,<3.0.0',
 'matplotlib>=3.10.0,<4.0.0',
 'mplcursors>=0.6,<0.7',
 'networkx>=3.4.2,<4.0.0',
 'numpy>=2.2.2,<3.0.0',
 'openai>=1.61.0,<2.0.0',
 'pydantic>=2.10.6,<3.0.0',
 'pydot>=3.0.4,<4.0.0',
 'python-dotenv>=1.0.1,<2.0.0']

setup_kwargs = {
    'name': 'cot2tot',
    'version': '0.1.0',
    'description': 'A tool for converting chain-of-thought outputs into tree-of-thought visualizations.',
    'long_description': '![Logo](assets/logo.png)\n# CoT2ToT: Chain-of-Thought to Tree-of-Thoughts\n\nCoT2ToT is a Python package that processes and visualizes chain-of-thought (CoT) outputs from language models by converting them into structured graphs (trees). This tool helps you analyze and explore the reasoning steps generated by an LLM.\n\n![Example GIF](assets/example.gif)\n\n## Features\n\n- **CoT Parsing:**\n  Convert raw LLM outputs into structured `ChainOfThoughts` objects.\n  - **LLM Extraction:** Automatically parse CoT outputs using the language model.\n  - **Manual Extraction:** Use predefined delimiters to segment and extract reasoning steps.\n\n- **Graph Construction:**\n  Transform a `ChainOfThoughts` object into a `GraphOfThoughts` directed graph, representing individual thoughts as nodes and their relationships as edges.\n\n- **Visualization:**\n  Visualize graphs using:\n  - **Static Tree Plot:** A hierarchical display of the reasoning graph.\n  - **Animated Tree:** An animated visualization that reveals nodes and edges gradually, with optional reasoning text. Animations can be saved as GIFs.\n\n- **Command-Line Interface (CLI):**\n  A CLI tool (`quick_start.py`) that allows you to run the different steps—parsing, graph conversion, and visualization—from the command line.\n\n## Repository Structure\n\n- **cot2tot/**\n  The core package directory containing:\n  - `models.py`: Data models (e.g., `Thought`, `ChainOfThoughts`, `GraphOfThoughts`).\n  - `parser.py`: Functions to parse LLM outputs into CoT objects and convert them into graphs.\n  - `utils.py`: Utility functions for text processing and tree layout computations.\n  - `visualize.py`: Functions for static and animated visualization of graphs.\n\n- **tests/**\n  Unit tests for the package:\n  - `test_models.py`\n  - `test_parser.py`\n  - `test_utils.py`\n  - `test_visualize.py`\n  - **test/fixtures/**\n    Sample data files used in tests and demonstrations.\n\n- **quick_start.py**\n  A command-line interface tool for running parsing, graph conversion, and visualization tasks.\n\n\n\n- **pyproject.toml**\n  Poetry configuration file that manages dependencies and package metadata.\n\n## Installation with Poetry\n\nCoT2ToT uses [Poetry](https://python-poetry.org/) for dependency management and packaging.\n\n```bash\ngit clone https://github.com/your_username/cot2tot.git\ncd cot2tot\npoetry install\n```\n\n## Usage\n\nYou can create a CoT2ToT instance by using your own LLM enpoint and key which will be used with the OpenAI python library. Once a graph is created, you can plot it or animate it.\n\n```python\nfrom cot2tot import CoT2ToT, CoT2ToTConfig\n\nconfig = CoT2ToTConfig(\n    llm_endpoint="<YOUR ENDPOINT>",\n    llm_key="<YOUR KEY>",\n    llm_model="<CHOSEN LLM MODEL>"\n)\n\ncot2tot_instance = CoT2ToT(config)\n\nexample_reasoning = "<|begin_of_thought|>[....]<|end_of_solution|>"\n\ncot2tot_instance.run_pipeline(example_reasoning, verbose=True, plot=False)\n\ncot2tot_instance.plot()\n\ncot2tot_instance.animate(save_file_name="example_video.gif")\n```\n\n## CLI\n\nThe package includes an CLI tool (`cli_quick_start.py`) for running different processing steps.\n\n### 1. Parsing an LLM Output\n\nConvert an LLM output file into a `ChainOfThoughts` object.\nYou can choose between LLM extraction (default) or manual extraction.\n\n```bash\npoetry run python quick_start.py parse --input path/to/llm_output.json --output parsed_cot.json\n```\n\nFor manual extraction:\n\n```bash\npoetry run python quick_start.py parse --input path/to/llm_output.json --method manual --output parsed_cot.json\n```\n\n### 2. Converting a CoT to a Graph\n\nConvert a parsed `ChainOfThoughts` JSON file into a `GraphOfThoughts`.\n\n```bash\npoetry run python quick_start.py graph --input parsed_cot.json --output graph.json\n```\n\n### 3. Visualizing a Graph\n\nVisualize a graph from a JSON file either as a static plot or an animated visualization.\n\nStatic tree plot:\n\n```bash\npoetry run python quick_start.py visualize --input graph.json\n```\n\nAnimated visualization (with reasoning text and GIF saving):\n\n```bash\npoetry run python quick_start.py visualize --input graph.json --animate --show_reasoning --speed 0.3 --save tree_animation.gif\n```\n\n## Running Tests\n\nTo run the tests with Poetry:\n\n```bash\npoetry run pytest\n```\n\n## Contributing\n\nContributions are welcome! Please open issues or submit pull requests for improvements and bug fixes.\n\n## License\n\nThis project is licensed under the Apache-2.0 License. See the [LICENSE](LICENSE) file for details.\n',
    'author': 'vale95ntino',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
